==> jc-1.4.0.tar.gz: javax/swing/ViewportLayout.h <==
// public class javax.swing.ViewportLayout

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b4638eb1efea0509 javax_swing_ViewportLayout

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_ViewportLayout_H_
#define _JC_javax_swing_ViewportLayout_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_ViewportLayout$sub_refs	_jc_javax_swing_ViewportLayout$sub_refs;
typedef struct _jc_javax_swing_ViewportLayout$sub_nonrefs	_jc_javax_swing_ViewportLayout$sub_nonrefs;
typedef struct _jc_javax_swing_ViewportLayout$refs	_jc_javax_swing_ViewportLayout$refs;
typedef struct _jc_javax_swing_ViewportLayout$nonrefs	_jc_javax_swing_ViewportLayout$nonrefs;
typedef struct _jc_javax_swing_ViewportLayout$object	_jc_javax_swing_ViewportLayout$object;

typedef struct _jc_javax_swing_ViewportLayout$fields_struct	_jc_javax_swing_ViewportLayout$fields_struct;
typedef const struct _jc_javax_swing_ViewportLayout$vmethods	_jc_javax_swing_ViewportLayout$vmethods;
typedef const struct _jc_javax_swing_ViewportLayout$vtable	_jc_javax_swing_ViewportLayout$vtable;
typedef const struct _jc_javax_swing_ViewportLayout$vtype	_jc_javax_swing_ViewportLayout$vtype;

// Class fields structure
struct _jc_javax_swing_ViewportLayout$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_ViewportLayout$fields_struct _jc_javax_swing_ViewportLayout$class_fields;

// Constructors
extern void _jc_javax_swing_ViewportLayout$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *);

// Virtual methods
extern void _jc_javax_swing_ViewportLayout$method$addLayoutComponent$784c308b12270c9d(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *);
extern void _jc_javax_swing_ViewportLayout$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_ViewportLayout$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_ViewportLayout$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *);
extern void _jc_javax_swing_ViewportLayout$method$removeLayoutComponent$94e2b376e31bbde2(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Component$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$addLayoutComponent$784c308b12270c9d;
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$removeLayoutComponent$94e2b376e31bbde2;

// Virtual methods structure
struct _jc_javax_swing_ViewportLayout$vmethods {
	void	(*addLayoutComponent$784c308b12270c9d)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *);
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *);
	void	(*removeLayoutComponent$94e2b376e31bbde2)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Component$object *);
};

// Vtable
struct _jc_javax_swing_ViewportLayout$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ViewportLayout$vmethods	javax_swing_ViewportLayout;
};

// Vtype
struct _jc_javax_swing_ViewportLayout$vtype {
	_jc_type			type;
	_jc_javax_swing_ViewportLayout$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ViewportLayout$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_ViewportLayout$refs {
    _jc_javax_swing_ViewportLayout$sub_refs	javax_swing_ViewportLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ViewportLayout$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ViewportLayout$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ViewportLayout$sub_nonrefs	javax_swing_ViewportLayout;
};

// Object instance structure
struct _jc_javax_swing_ViewportLayout$object {
	_jc_javax_swing_ViewportLayout$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ViewportLayout$vtype	*vtype;
	_jc_javax_swing_ViewportLayout$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ViewportLayout$vtype _jc_javax_swing_ViewportLayout$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ViewportLayout, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ViewportLayout$class_object;

#endif	/* _JC_javax_swing_ViewportLayout_H_ */

==> jc-1.4.6.tar.gz: javax/swing/ViewportLayout.h <==
// public class javax.swing.ViewportLayout

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b4638eb1efea0509 javax_swing_ViewportLayout

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_ViewportLayout_H_
#define _JC_javax_swing_ViewportLayout_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_ViewportLayout$sub_refs	_jc_javax_swing_ViewportLayout$sub_refs;
typedef struct _jc_javax_swing_ViewportLayout$sub_nonrefs	_jc_javax_swing_ViewportLayout$sub_nonrefs;
typedef struct _jc_javax_swing_ViewportLayout$refs	_jc_javax_swing_ViewportLayout$refs;
typedef struct _jc_javax_swing_ViewportLayout$nonrefs	_jc_javax_swing_ViewportLayout$nonrefs;
typedef struct _jc_javax_swing_ViewportLayout$object	_jc_javax_swing_ViewportLayout$object;

typedef struct _jc_javax_swing_ViewportLayout$fields_struct	_jc_javax_swing_ViewportLayout$fields_struct;
typedef const struct _jc_javax_swing_ViewportLayout$vmethods	_jc_javax_swing_ViewportLayout$vmethods;
typedef const struct _jc_javax_swing_ViewportLayout$vtable	_jc_javax_swing_ViewportLayout$vtable;
typedef const struct _jc_javax_swing_ViewportLayout$vtype	_jc_javax_swing_ViewportLayout$vtype;

// Class fields structure
struct _jc_javax_swing_ViewportLayout$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_ViewportLayout$fields_struct _jc_javax_swing_ViewportLayout$class_fields;

// Constructors
extern void _jc_javax_swing_ViewportLayout$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_ViewportLayout$method$addLayoutComponent$784c308b12270c9d(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_ViewportLayout$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_ViewportLayout$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_ViewportLayout$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_ViewportLayout$method$removeLayoutComponent$94e2b376e31bbde2(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$addLayoutComponent$784c308b12270c9d;
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_ViewportLayout$method_info$removeLayoutComponent$94e2b376e31bbde2;

// Virtual methods structure
struct _jc_javax_swing_ViewportLayout$vmethods {
	void	(*addLayoutComponent$784c308b12270c9d)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	void	(*removeLayoutComponent$94e2b376e31bbde2)(_jc_env *, struct _jc_javax_swing_ViewportLayout$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_ViewportLayout$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ViewportLayout$vmethods	javax_swing_ViewportLayout;
};

// Vtype
struct _jc_javax_swing_ViewportLayout$vtype {
	_jc_type			type;
	_jc_javax_swing_ViewportLayout$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ViewportLayout$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_ViewportLayout$refs {
    _jc_javax_swing_ViewportLayout$sub_refs	javax_swing_ViewportLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ViewportLayout$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ViewportLayout$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ViewportLayout$sub_nonrefs	javax_swing_ViewportLayout;
};

// Object instance structure
struct _jc_javax_swing_ViewportLayout$object {
	_jc_javax_swing_ViewportLayout$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ViewportLayout$vtype	*vtype;
	_jc_javax_swing_ViewportLayout$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ViewportLayout$vtype _jc_javax_swing_ViewportLayout$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ViewportLayout, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ViewportLayout$class_object;

#endif	/* _JC_javax_swing_ViewportLayout_H_ */
